@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.26.1";
+our $VERSION = "v6.26.2";
 
 1;
 __END__
@@ -128,16 +128,19 @@ L<https://rxjs.dev/api/index/function/concat>
 
 L<https://rxjs.dev/api/index/function/defer>
 
-    # Suppose "int rand 10" here evaluates to 7. Then if after 7 seconds $special_var holds a true value,
-    # output will be: 0, 1, 2, 3, 4, 5, 6, 10, 20, 30, complete, otherwise it will be:
-    # 0, 1, 2, 3, 4, 5, 6, 40, 50, 60, complete.
+    my $special_var;
 
-    rx_concat(
-        rx_interval(1)->pipe( op_take(int rand 10) ),
-        rx_defer(sub {
-            return $special_var ? rx_of(10, 20, 30) : rx_of(40, 50, 60)
-        })
-    )->subscribe($observer);
+    my $o = rx_defer(sub {
+        return $special_var ? rx_of(10, 20, 30) : rx_of(40, 50, 60)
+    })
+
+    # 10, 20, 30, complete
+    $special_var = 1;
+    $o->subscribe($observer);
+
+    # 40, 50, 60, complete
+    $special_var = 0;
+    $o->subscribe($observer);
 
 =item rx_EMPTY
 
@@ -426,7 +429,7 @@ Works like rxjs's "auditTime", except the parameter is in seconds instead of ms.
     # 30, complete
     rx_concat(
         rx_of(10, 20, 30),
-        rx_EMPTY->pipe( op_delay(5) ),
+        rx_timer(5)->pipe( op_ignore_elements ),
     )->pipe(
         op_audit_time(1),
     )->subscribe($observer);
